const Main = imports.ui.main;
const Config = imports.misc.config;
const Me = imports.misc.extensionUtils.getCurrentExtension();
const { Gio, GLib } = imports.gi;
const { main, messageTray } = imports.ui;
const Log = Me.imports.modules.log;
const Panel = Me.imports.modules.panel;
var Extension = class Extension {
    constructor() {
        this.gpuModeIndicatorInstance = null;
        this.gpuModeClient = null;
        this.systemMenu = null;
        this.title = "Super Graphics Control";
    }
    enable() {
        this.systemMenu = this.getSystemMenu();
        if (typeof this.systemMenu == 'undefined') {
            Log.raw('init', 'system menu is not defined');
            return false;
        }
        if (this.systemMenu._powerProfiles) {
            this.gpuModeIndicatorInstance = new Panel.gpuModeIndicator();
            this.systemMenu._indicators.remove_child(this.systemMenu._power);
            this.systemMenu._indicators.add_child(this.gpuModeIndicatorInstance);
            const menuItems = this.systemMenu.menu._getMenuItems();
            const powerMenuItemIndex = this.systemMenu._powerProfiles ? menuItems.indexOf(this.systemMenu._powerProfiles.menu) : -1;
            const menuIndex = powerMenuItemIndex > -1 ? powerMenuItemIndex + 1 : 3;
            this.systemMenu.menu.addMenuItem(this.gpuModeIndicatorInstance.menu, menuIndex);
            this.systemMenu._indicators.add_child(this.systemMenu._power);
        }
    }
    disable() {
        this.gpuModeIndicatorInstance.stop();
        this.gpuModeIndicatorInstance.destroy();
        this.gpuModeIndicatorInstance = null;
    }
    getSystemMenu() {
        if (parseInt(Config.PACKAGE_VERSION) < 43) {
            return Main.panel.statusArea.aggregateMenu;
        }
        else {
            return Main.panel.statusArea.quickSettings;
        }
    }
    spawnCommandLine(command) {
        try {
            GLib.spawn_command_line_async(command);
        }
        catch (e) {
            Log.error(`Spawning command failed: ${command}`, e);
        }
    }
    notify(msg = this.title, details, icon, action = "") {
        let gIcon = Gio.icon_new_for_string(`${Me.path}/icons/${icon}`);
        let params = { gicon: gIcon };
        let source = new messageTray.Source(msg, icon, params);
        let notification = new messageTray.Notification(source, msg, details, params);
        main.messageTray.add(source);
        notification.setTransient(true);
        if (action == "reboot") {
            notification.setUrgency(3);
            notification.addAction("Reboot Now!", () => {
                this.spawnCommandLine("systemctl reboot");
            });
        }
        else if (action == "logout") {
            notification.setUrgency(3);
            notification.addAction("Log Out Now!", () => {
                this.spawnCommandLine("gnome-session-quit");
            });
        }
        else {
            notification.setUrgency(2);
        }
        source.showNotification(notification);
    }
}
function init() {
    ext = new Extension();
    return ext;
}
//# sourceMappingURL=extension.js.map